#
# spec file for package swaybg
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           swaybg
Version:        1.2.1
Release:        1.3
Summary:        Wallpaper tool for Wayland compositors
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/swaywm/swaybg
Source0:        https://github.com/swaywm/swaybg/releases/download/v%{version}/swaybg-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRequires:  meson >= 0.48.0
BuildRequires:  pkgconfig
BuildRequires:  scdoc
BuildRequires:  wlroots-devel >= 0.5
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.26
BuildRequires:  pkgconfig(wayland-server)
BuildRequires:  pkgconfig(xkbcommon)

%description
swaybg is a wallpaper utility for Wayland compositors. It is compatible with any Wayland compositor which implements the following Wayland protocols:
wlr-layer-shell, xdg-output, xdg-shell.

%prep
%setup -q

%build
export CFLAGS="%{optflags}"
%meson

%meson_build

%install
%meson_install

%files
%license LICENSE
%doc README.md
%{_bindir}/swaybg
%{_mandir}/man1/swaybg.1%{?ext_man}

%changelog
* Mon Apr 29 2024 Michael Vetter <mvetter@suse.com>
- Update to 1.2.1:
  * Unify color validation and parsing functions
  * Document option arguments in command line usage
  * Correct for image orientation when loading image
  * wayland-protocols min. version to 1.26
  * main.c: fix build against gcc-14 (-Walloc-size)
  * build: find native wayland-scanner program
  * build: drop intermediate protocols library
* Tue Jan 17 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * man: fix background color input format
  * Use shm_open instead of mkstemp for anon files
  * Check wl_display_roundtrip return value
  * readme: drop mention of xdg-shell requirement
  * build: stop using join_paths
  * build: stop using sh for scdoc
  * Replace xdg_output with wl_output v4
  * Optimize solid color with single-pixel-buffer-v1
* Thu Mar 10 2022 Michael Vetter <mvetter@suse.com>
- Update to 1.1.1:
  * Add editorconfig
  * Only render a new frame when the buffer size changes
  * Fix memory leak when using image tile mode
* Tue Jul 20 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.1:
  * This release contains performance improvements: swaybg should use less
    memory and load faster.
* Thu May  7 2020 Michael Vetter <mvetter@suse.com>
- Remove dependency on wlc. It is long deprecated and actually
  wlroots is used.
* Tue Jun  4 2019 mvetter@suse.com
- Initial package of swaybg in 1.0 for openSUSE
